Learn R Programming

lab2clean (version 2.0.0)

RWD_units_to_UCUM_V2: Data for the RWD units mapped to standard UCUM-valid units

Description

A dataset containing RWD units mapped to standard UCUM-valid units.

Usage

data(RWD_units_to_UCUM_V2)

Arguments

Format

A data frame with N rows and 3 variables:

clean_unit_lower

Case-insensitive representation of invalid or inconsistent units as found in real-world data (RWD).

ucum_code

The equivalent UCUM-compliant format for the given RWD unit.

source_match

The source from which this mapping or match was derived.

A data frame with 5120 rows and 3 variables.