Learn R Programming

lab2clean (version 2.0.0)

parsed_units_df: Data for the parsed UCUM units

Description

Intermediate dataset representing parsed UCUM units and the parameters necessary for machine readability and conversion.

Usage

data(parsed_units_df)

Arguments

Format

A data frame with 1439 rows and 8 variables.

Details

csCode_

Case-sensitive code.

ciCode_

Case-insensitive code.

magnitude_

Magnitude of the unit.

dim_

The dimensionality of the unit (e.g., mass/time).

cnv_

Special conversion involved (if any).

cnvPfx_

Prefix used in the special conversion.

isArbitrary_

Logical flag indicating if the unit is arbitrary.

moleExp_

Logical flag indicating if the unit includes molar expression.