A dataset containing RWD units mapped to standard UCUM-valid units.
data(RWD_units_to_UCUM_V2)A data frame with N rows and 3 variables:
Case-insensitive representation of invalid or inconsistent units as found in real-world data (RWD).
The equivalent UCUM-compliant format for the given RWD unit.
The source from which this mapping or match was derived.
A data frame with 5120 rows and 3 variables.