Intermediate dataset representing parsed UCUM units and the parameters necessary for machine readability and conversion.
data(parsed_units_df)A data frame with 1439 rows and 8 variables.
Case-sensitive code.
Case-insensitive code.
Magnitude of the unit.
The dimensionality of the unit (e.g., mass/time).
Special conversion involved (if any).
Prefix used in the special conversion.
Logical flag indicating if the unit is arbitrary.
Logical flag indicating if the unit includes molar expression.